@@ -1,12 +1,12 @@
 package Sah::Schema::date::dow_nums;
 
-our $DATE = '2019-07-21'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2019-11-28'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 our $schema = ['array' => {
     summary => 'Array of day-of-week numbers (1-7, 1=Monday)',
     of => ['date::dow_num', {}, {}],
-    'x.perl.coerce_rules' => ['str_comma_sep'],
+    'x.perl.coerce_rules' => ['From_str::comma_sep'],
     'x.completion' => ['date_dow_nums'],
 }, {}];
 
@@ -26,7 +26,7 @@ Sah::Schema::date::dow_nums - Array of day-of-week numbers (1-7, 1=Monday)
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::date::dow_nums (from Perl distribution Sah-Schemas-Date), released on 2019-07-21.
+This document describes version 0.007 of Sah::Schema::date::dow_nums (from Perl distribution Sah-Schemas-Date), released on 2019-11-28.
 
 =head1 HOMEPAGE
 
