@@ -1,13 +1,13 @@
 package Sah::Schema::date::month_num;
 
-our $DATE = '2019-07-21'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2019-11-28'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 our $schema = [int => {
     summary => 'Month number',
     min => 1,
     max => 12,
-    'x.perl.coerce_rules' => ['str_convert_en_month_name_to_num'],
+    'x.perl.coerce_rules' => ['From_str::convert_en_month_name_to_num'],
     'x.completion' => ['date_month_num'],
 }, {}];
 
@@ -27,7 +27,7 @@ Sah::Schema::date::month_num - Month number
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::date::month_num (from Perl distribution Sah-Schemas-Date), released on 2019-07-21.
+This document describes version 0.007 of Sah::Schema::date::month_num (from Perl distribution Sah-Schemas-Date), released on 2019-11-28.
 
 =head1 HOMEPAGE
 
